exceptiontools.TimeSignatureError
=================================

.. inheritance-diagram:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureError.TimeSignatureError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
